#ifndef NT2_INCLUDE_FUNCTIONS_FUZZY_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FUZZY_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/fuzzy_equal.hpp>

#endif
